pub struct OpenOptions { /* private fields */ }
Available on crate feature tokio only.
Options and flags which can be used to configure how a file is opened.

This is a wrapper around tokio::fs::OpenOptions.

Implementations

Creates a blank new set of options ready for configuration.

All options are initially set to false.

This is a wrapped version of tokio::fs::OpenOptions::new

Examples
use fs_err::tokio::OpenOptions;

let mut options = OpenOptions::new();
let future = options.read(true).open("foo.txt");